Error

Enum Error 

pub enum Error {
    Pool(RunError<Error>),
    Db(Error),
    MissingExtension,
    OverlappingExtractors,
}
Errors that can occur when using this crate.

Variants



Pool(RunError<Error>)

Failed to obtain a connection from the pool.



Db(Error)

A PostgreSQL error occurred while executing a query or transaction.



MissingExtension

The Layer was not applied to the router.

This occurs when Tx is extracted in a handler but the request was not processed by the transaction Layer.



OverlappingExtractors

Tx was extracted multiple times in the same handler or middleware.

Only one Tx extractor can be used per request. If you need to run multiple queries, use the same transaction for all of them.