Tx

Struct Tx 

pub struct Tx<E = Error> { /* private fields */ }

Methods from Deref<Target = Transaction<'static>>

pub async fn prepare(&self, query: &str) -> Result<Statement, Error>

Like Client::prepare.

pub async fn prepare_typed( &self, query: &str, parameter_types: &[Type], ) -> Result<Statement, Error>

Like Client::prepare_typed.

pub async fn query<T>( &self, statement: &T, params: &[&(dyn ToSql + Sync)], ) -> Result<Vec<Row>, Error>
where T: ToStatement + ?Sized,

Like Client::query.

pub async fn query_one<T>( &self, statement: &T, params: &[&(dyn ToSql + Sync)], ) -> Result<Row, Error>
where T: ToStatement + ?Sized,

Like Client::query_one.

pub async fn query_opt<T>( &self, statement: &T, params: &[&(dyn ToSql + Sync)], ) -> Result<Option<Row>, Error>
where T: ToStatement + ?Sized,

Like Client::query_opt.

pub async fn query_raw<T, P, I>( &self, statement: &T, params: I, ) -> Result<RowStream, Error>

Like Client::query_raw.

pub async fn query_typed( &self, statement: &str, params: &[(&(dyn ToSql + Sync), Type)], ) -> Result<Vec<Row>, Error>

Like Client::query_typed.

pub async fn query_typed_raw<P, I>( &self, query: &str, params: I, ) -> Result<RowStream, Error>
where P: BorrowToSql, I: IntoIterator<Item = (P, Type)>,

Like Client::query_typed_raw.

pub async fn execute<T>( &self, statement: &T, params: &[&(dyn ToSql + Sync)], ) -> Result<u64, Error>
where T: ToStatement + ?Sized,

Like Client::execute.

pub async fn execute_raw<P, I, T>( &self, statement: &T, params: I, ) -> Result<u64, Error>

Like Client::execute_iter.

pub async fn bind<T>( &self, statement: &T, params: &[&(dyn ToSql + Sync)], ) -> Result<Portal, Error>
where T: ToStatement + ?Sized,

Binds a statement to a set of parameters, creating a Portal which can be incrementally queried.

Portals only last for the duration of the transaction in which they are created, and can only be used on the connection that created them.

Panics

Panics if the number of parameters provided does not match the number expected.

pub async fn bind_raw<P, T, I>( &self, statement: &T, params: I, ) -> Result<Portal, Error>

A maximally flexible version of bind.

pub async fn query_portal( &self, portal: &Portal, max_rows: i32, ) -> Result<Vec<Row>, Error>

Continues execution of a portal, returning a stream of the resulting rows.

Unlike query, portals can be incrementally evaluated by limiting the number of rows returned in each call to query_portal. If the requested number is negative or 0, all rows will be returned.

pub async fn query_portal_raw( &self, portal: &Portal, max_rows: i32, ) -> Result<RowStream, Error>

The maximally flexible version of query_portal.

pub async fn copy_in<T, U>(&self, statement: &T) -> Result<CopyInSink<U>, Error>
where T: ToStatement + ?Sized, U: Buf + 'static + Send,

Like Client::copy_in.

pub async fn copy_out<T>(&self, statement: &T) -> Result<CopyOutStream, Error>
where T: ToStatement + ?Sized,

Like Client::copy_out.

pub async fn simple_query( &self, query: &str, ) -> Result<Vec<SimpleQueryMessage>, Error>

Like Client::simple_query.

pub async fn batch_execute(&self, query: &str) -> Result<(), Error>

Like Client::batch_execute.

pub fn cancel_token(&self) -> CancelToken

Like Client::cancel_token.

pub async fn cancel_query<T>(&self, tls: T) -> Result<(), Error>

👎Deprecated since 0.6.0: use Transaction::cancel_token() instead

Like Client::cancel_query.

pub async fn cancel_query_raw<S, T>( &self, stream: S, tls: T, ) -> Result<(), Error>
where S: AsyncRead + AsyncWrite + Unpin, T: TlsConnect<S>,

👎Deprecated since 0.6.0: use Transaction::cancel_token() instead

Like Client::cancel_query_raw.

pub fn client(&self) -> &Client

Returns a reference to the underlying Client.